==> hildonmm_0.9.7-2.tar.gz: hildonmm-0.9.7/tools/extra_defs_gen/generate_defs_hildon.cc <==
/* $Id: generate_defs_gda.cc,v 1.9 2005/09/22 06:39:23 murrayc Exp $ */

/* generate_defs_gda.h
 *
 * Copyright 2005-2007 The maemomm development team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "glibmm_generate_extra_defs/generate_extra_defs.h"

#include <hildon/hildon.h>
#include <hildon/hildon-calendar-popup.h>
#include <hildon/hildon-color-button.h>
//These were removed during the libhildon->hildon1 transition, it seems:
//#include <hildon/hildon-color-popup.h>
//#include <hildon/hildon-color-selector.h>

#include <hildon/hildon-controlbar.h>
#include <hildon/hildon-date-editor.h>

//This was moved to hildon-help during the libhildon->hildon1 transition, apparently:
//#include <hildon/hildon-dialoghelp.h>

/* This is hildon-fmmm #include <hildon/hildon-file-details-dialog.h> */
#include <hildon/hildon-font-selection-dialog.h>
#include <hildon/hildon-get-password-dialog.h>
#include <hildon/hildon-hvolumebar.h>
//#include <hildon/hildon-insert-object-dialog.h>
#include <hildon/hildon-login-dialog.h>
#include <hildon/hildon-note.h>
#include <hildon/hildon-number-editor.h>
#include <hildon/hildon-range-editor.h>

//TODO: This will be replaced by something else, apparently. murrayc:
//#include <hildon/hildon-scroll-area.h>

#include <hildon/hildon-seekbar.h>
#include <hildon/hildon-set-password-dialog.h>
#include <hildon/hildon-sort-dialog.h>
//#include <hildon/hildon-system-sound.h>

// FIXME: temporary workaround for MB#814
#if 0
#include <hildon/hildon-time-editor.h>
#else
#define HILDON_TYPE_TIME_EDITOR (hildon_time_editor_get_type())
extern "C" { GType hildon_time_editor_get_type(void) G_GNUC_CONST; }
#endif

#include <hildon/hildon-time-picker.h>
#include <hildon/hildon-volumebar.h>
//#include <hildon/hildon-volumebar-range.h>
#include <hildon/hildon-vvolumebar.h>
#include <hildon/hildon-weekday-picker.h>
#include <hildon/hildon-window.h>
#include <hildon/hildon-wizard-dialog.h>

//TODO: What happened to this during the libhildon->hildon1 transition?
//#include <hildon/hildon-input-mode-hint.h>

#include <hildon/hildon-find-toolbar.h>
#include <hildon/hildon-caption.h>
#include <hildon/hildon-program.h>
#include <hildon/hildon-banner.h>

#include <gtk/gtk.h>



int main (int argc, char *argv[])
{
    gtk_init(&argc, &argv);

    std::cout << get_defs(HILDON_TYPE_CAPTION)
              << get_defs(HILDON_TYPE_CALENDAR_POPUP)
              << get_defs(HILDON_TYPE_CODE_DIALOG)
              << get_defs(HILDON_TYPE_DATE_EDITOR)
/* deprecated: << get_defs(HILDON_TYPE_FILE_HANDLING_NOTE) */
              << get_defs(HILDON_TYPE_FIND_TOOLBAR)
              << get_defs(HILDON_TYPE_NOTE)
              << get_defs(HILDON_TYPE_TIME_PICKER)
              << get_defs(HILDON_TYPE_LOGIN_DIALOG)
              << get_defs(HILDON_TYPE_VVOLUMEBAR)
             // << get_defs(HILDON_TYPE_INSERT_OBJECT_DIALOG)
              << get_defs(HILDON_TYPE_SEEKBAR)
              << get_defs(HILDON_TYPE_RANGE_EDITOR)

              << get_defs(HILDON_TYPE_TIME_EDITOR)
              << get_defs(HILDON_TYPE_SORT_DIALOG)
              << get_defs(HILDON_TYPE_FONT_SELECTION_DIALOG)
              << get_defs(HILDON_TYPE_COLOR_BUTTON)
              << get_defs(HILDON_TYPE_VOLUMEBAR)
              << get_defs(HILDON_TYPE_CONTROLBAR)
              << get_defs(HILDON_TYPE_GET_PASSWORD_DIALOG)
              << get_defs(HILDON_TYPE_SET_PASSWORD_DIALOG)
              << get_defs(HILDON_TYPE_WIZARD_DIALOG)
              << get_defs(HILDON_TYPE_NUMBER_EDITOR) 
              << get_defs(HILDON_TYPE_WINDOW)
              << get_defs(HILDON_TYPE_PROGRAM)
              << get_defs(HILDON_TYPE_BANNER)
              << std::endl;

              //Deprecated or removed:
	      //<< get_defs(HILDON_TYPE_ADD_HOME_DIALOG)
              //<< get_defs(HILDON_TYPE_COLOR_SELECTOR)
              //<< get_defs(HILDON_TYPE_GRID)
              //<< get_defs(HILDON_TYPE_GRID_ITEM)
              //<< get_defs(HILDON_TELEPHONE_EDITOR_TYPE)

    return 0;
}

==> hildonmm_2.0.1-1.tar.gz: hildonmm-2.0.1/tools/extra_defs_gen/generate_defs_hildon.cc <==
/* $Id: generate_defs_gda.cc,v 1.9 2005/09/22 06:39:23 murrayc Exp $ */

/* generate_defs_gda.h
 *
 * Copyright 2005-2007 The maemomm development team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "glibmm_generate_extra_defs/generate_extra_defs.h"

#include <hildon/hildon.h>
#include <hildon/hildon-calendar-popup.h>
#include <hildon/hildon-color-button.h>
#if 0
G_BEGIN_DECLS /* Workaround for #3398 */
#include <hildon/hildon-color-chooser.h>
#include <hildon/hildon-color-chooser-dialog.h>
G_END_DECLS
#endif

#include <hildon/hildon-controlbar.h>
#include <hildon/hildon-date-editor.h>

#include <hildon/hildon-font-selection-dialog.h>
#include <hildon/hildon-get-password-dialog.h>
#include <hildon/hildon-hvolumebar.h>
#include <hildon/hildon-login-dialog.h>
#include <hildon/hildon-note.h>
#include <hildon/hildon-number-editor.h>
#include <hildon/hildon-range-editor.h>
#include <hildon/hildon-seekbar.h>
#include <hildon/hildon-set-password-dialog.h>
#include <hildon/hildon-sort-dialog.h>
#include <hildon/hildon-time-editor.h>
#include <hildon/hildon-time-picker.h>
#include <hildon/hildon-volumebar.h>
#include <hildon/hildon-vvolumebar.h>
#include <hildon/hildon-weekday-picker.h>
#include <hildon/hildon-window.h>
#include <hildon/hildon-wizard-dialog.h>
#include <hildon/hildon-find-toolbar.h>
#include <hildon/hildon-caption.h>
#include <hildon/hildon-program.h>
#include <hildon/hildon-banner.h>

#include <gtk/gtk.h>



int main (int argc, char *argv[])
{
    gtk_init(&argc, &argv);

    std::cout << get_defs(HILDON_TYPE_CAPTION)
              << get_defs(HILDON_TYPE_CALENDAR_POPUP)
              << get_defs(HILDON_TYPE_COLOR_BUTTON)
              //<< get_defs(HILDON_TYPE_COLOR_CHOOSER)              
              //<< get_defs(HILDON_TYPE_COLOR_CHOOSER_DIALOG)
              << get_defs(HILDON_TYPE_CODE_DIALOG)
              << get_defs(HILDON_TYPE_DATE_EDITOR)
              << get_defs(HILDON_TYPE_FIND_TOOLBAR)
              << get_defs(HILDON_TYPE_NOTE)
              << get_defs(HILDON_TYPE_TIME_PICKER)
              << get_defs(HILDON_TYPE_LOGIN_DIALOG)
              << get_defs(HILDON_TYPE_VVOLUMEBAR)
              << get_defs(HILDON_TYPE_SEEKBAR)
              << get_defs(HILDON_TYPE_RANGE_EDITOR)
              << get_defs(HILDON_TYPE_TIME_EDITOR)
              << get_defs(HILDON_TYPE_SORT_DIALOG)
              << get_defs(HILDON_TYPE_FONT_SELECTION_DIALOG)
              << get_defs(HILDON_TYPE_COLOR_BUTTON)
              << get_defs(HILDON_TYPE_VOLUMEBAR)
              << get_defs(HILDON_TYPE_CONTROLBAR)
              << get_defs(HILDON_TYPE_GET_PASSWORD_DIALOG)
              << get_defs(HILDON_TYPE_SET_PASSWORD_DIALOG)
              << get_defs(HILDON_TYPE_WIZARD_DIALOG)
              << get_defs(HILDON_TYPE_NUMBER_EDITOR) 
              << get_defs(HILDON_TYPE_WINDOW)
              << get_defs(HILDON_TYPE_PROGRAM)
              << get_defs(HILDON_TYPE_BANNER)
              << std::endl;

    return 0;
}
